"""
Old-style. For backwards compatibility.
Avoid use.
"""

from yamcs.client.archive.model import (  # noqa
    ColumnData,
    IndexGroup,
    IndexRecord,
    ParameterRange,
    ParameterRangeEntry,
    ResultSet,
    Sample,
    Stream,
    StreamData,
    Table,
)
