"""
Old-style. For backwards compatibility.
Avoid use.
"""

from yamcs.client.tmtc.client import (  # noqa
    AlarmSubscription,
    CommandConnection,
    CommandHistorySubscription,
    ContainerSubscription,
    ParameterSubscription,
    ProcessorClient,
)
