"""
Old-style. For backwards compatibility.
Avoid use.
"""

from yamcs.client.model import (  # noqa
    AuthInfo,
    Event,
    Instance,
    InstanceTemplate,
    Link,
    LinkAction,
    LoadParameterValuesResult,
    ObjectPrivilege,
    Processor,
    RdbTablespace,
    ServerInfo,
    Service,
    UserInfo,
)
