"""
Old-style. For backwards compatibility.
Avoid use.
"""

from yamcs.client.core.exceptions import (  # noqa
    ConnectionFailure,
    NotFound,
    TimeoutError,
    Unauthorized,
    YamcsError,
)
