"""
Old-style. For backwards compatibility.
Avoid use.
"""

from yamcs.client.timeline.model import (  # noqa
    Band,
    CommandBand,
    Item,
    ItemBand,
    Spacer,
    TimeRuler,
    View,
)
